# setup.py
from setuptools import setup, find_packages

setup(
    name="eeman-boss",
    version="0.1.5",
    description="A fun chatbot that acts like Eeman Boss.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Syed Obaidullah Hassan Chishti",
    author_email="obaidullahhasan@gmail.com",
    url="https://github.com/obaidhsn/eeman-boss",
    packages=find_packages(),
    install_requires=[
        "openai"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)
